@@ -36,8 +36,13 @@ class SingleHostSession(requests.Session):
 
     def request(self, method, url, *args, **kwargs):
         url = urljoin(self.host, url)
-        return super(SingleHostSession, self).request(
-            method, url, *args, **kwargs
+        return super(SingleHostSession, self).request(method, url, *args, **kwargs)
+
+
+class APIRequestError(click.ClickException):
+    def show(self, file=None):
+        click.secho(
+            f"\nError: {self.format_message()}", file=file, err=True, fg="red"
         )
 
 
@@ -55,14 +60,7 @@ class APIRequest(object):
     headers = {}
 
     def __init__(
-        self,
-        session,
-        url=None,
-        url_kwargs=None,
-        data=None,
-        files=None,
-        *args,
-        **kwargs
+        self, session, url=None, url_kwargs=None, data=None, files=None, *args, **kwargs
     ):
         self.session = session
         if url:
@@ -114,10 +112,7 @@ class APIRequest(object):
                 *args,
                 **kwargs
             )
-        except (
-            requests.exceptions.ConnectionError,
-            requests.exceptions.Timeout,
-        ) as e:
+        except (requests.exceptions.ConnectionError, requests.exceptions.Timeout) as e:
             raise click.ClickException(messages.NETWORK_ERROR_MESSAGE + str(e))
 
         return self.verify(response)
@@ -128,13 +123,13 @@ class APIRequest(object):
                 response.status_code
             )
             if not error_msg:
-                response_content = response.content
+                response_content = response.text
                 if not self.session.debug:
                     response_content = response_content[:300]
                 error_msg = "{}\n\n{}".format(
                     self.default_error_message, response_content
                 )
-            raise click.ClickException(error_msg)
+            raise APIRequestError(error_msg)
         return self.process(response)
 
     def process(self, response):
