@@ -1,3 +1,4 @@
+import errno
 import json
 import os
 import re
@@ -15,7 +16,7 @@ from divio_cli.utils import get_local_git_remotes
 
 from . import utils
 from .. import settings
-from ..cloud import get_aldryn_host
+from ..cloud import get_divio_host
 from ..utils import (
     check_call,
     check_output,
@@ -27,7 +28,7 @@ from ..utils import (
 )
 
 
-DEFAULT_GIT_HOST = "git@git.{aldryn_host}"
+DEFAULT_GIT_HOST = "git@git.{divio_host}"
 GIT_CLONE_URL = "{git_host}:{project_slug}.git"
 
 
@@ -40,7 +41,7 @@ def get_git_host():
     if git_host:
         click.secho("Using custom git host {}\n".format(git_host), fg="yellow")
     else:
-        git_host = DEFAULT_GIT_HOST.format(aldryn_host=get_aldryn_host())
+        git_host = DEFAULT_GIT_HOST.format(divio_host=get_divio_host())
     return git_host
 
 
@@ -56,9 +57,7 @@ def clone_project(website_slug, path, client):
     click.secho("\ncloning project repository", fg="green")
     website_id = client.get_website_id_for_slug(website_slug)
 
-    website_git_url = get_git_clone_url(
-        website_slug, website_id, client=client
-    )
+    website_git_url = get_git_clone_url(website_slug, website_id, client=client)
     clone_args = ["git", "clone", website_git_url]
     if path:
         clone_args.append(path)
@@ -69,26 +68,46 @@ def clone_project(website_slug, path, client):
 def configure_project(website_slug, path, client):
     website_id = client.get_website_id_for_slug(website_slug)
 
-    # Detect old style or invalid projects
-    compose_config = os.path.join(path, "docker-compose.yml")
-    if not os.path.isfile(compose_config):
+    # create configuration file
+    website_data = {"id": website_id, "slug": website_slug}
+    if os.path.exists(os.path.join(path, settings.ALDRYN_DOT_FILE)):
+        path = os.path.join(path, settings.ALDRYN_DOT_FILE)
+    else:
+        path = os.path.join(path, settings.DIVIO_DOT_FILE)
+
+    # Create folders if they don't exist yet.
+    if not os.path.exists(os.path.dirname(path)):
+        try:
+            os.makedirs(os.path.dirname(path))
+        except OSError as exc:  # Guard against race condition
+            if exc.errno != errno.EEXIST:
+                raise
+
+    if not os.path.isdir(os.path.dirname(path)):
         raise click.ClickException(
-            "Could not find a valid 'docker-compose.yml' file. Please make "
-            "sure that this project has been updated on the Divio Cloud to "
-            "use Base Project version 3 or higher."
+            "{} is not a directory".format(os.path.dirname(path))
         )
 
-    # create .aldryn file
-    website_data = {"id": website_id, "slug": website_slug}
-    with open(os.path.join(path, settings.ALDRYN_DOT_FILE), "w+") as fh:
-        json.dump(website_data, fh)
-    
+    # Write the file
+    with open(path, "w+") as fh:
+        json.dump(website_data, fh, indent=4)
+
 
 def setup_website_containers(client, stage, path, prefix=DEFAULT_SERVICE_PREFIX):
-    docker_compose = utils.get_docker_compose_cmd(path)
+    try:
+        docker_compose = utils.get_docker_compose_cmd(path)
+    except RuntimeError:
+        # Docker-compose does not exist
+        click.secho(
+            "Warning: docker-compose.yml does not exist. Will continue without...",
+            fg="red"
+        )
+        return
     docker_compose_config = utils.DockerComposeConfig(docker_compose)
 
-    if docker_compose_config.has_service("db") or docker_compose_config.has_service("database_{}".format(prefix).lower()) :
+    if docker_compose_config.has_service("db") or docker_compose_config.has_service(
+        "database_{}".format(prefix).lower()
+    ):
         has_db_service = True
         existing_db_container_id = utils.get_db_container_id(
             path=path, raise_on_missing=False
@@ -121,8 +140,10 @@ def setup_website_containers(client, stage, path, prefix=DEFAULT_SERVICE_PREFIX)
         click.secho("creating new database container", fg="green")
 
         db_type = utils.get_db_type(prefix, path=path)
-        
-        ImportRemoteDatabase(client=client, stage=stage, path=path, prefix=prefix, db_type=db_type)()
+
+        ImportRemoteDatabase(
+            client=client, stage=stage, path=path, prefix=prefix, db_type=db_type
+        )()
 
         click.secho("syncing and migrating database", fg="green")
 
@@ -133,17 +154,17 @@ def setup_website_containers(client, stage, path, prefix=DEFAULT_SERVICE_PREFIX)
             check_call(docker_compose("run", "-d", "web", "start", "migrate"))
             sleep(30)
         else:
-            check_call(docker_compose("run", "web", "/bin/bash","-c", "sleep 5; start migrate"))
+            check_call(
+                docker_compose(
+                    "run", "web", "/bin/bash", "-c", "sleep 5; start migrate"
+                )
+            )
 
 
-def create_workspace(
-    client, website_slug, stage, path=None, force_overwrite=False
-):
+def create_workspace(client, website_slug, stage, path=None, force_overwrite=False):
     click.secho("Creating workspace", fg="green")
 
-    path = os.path.abspath(
-        os.path.join(path, website_slug) if path else website_slug
-    )
+    path = os.path.abspath(os.path.join(path, website_slug) if path else website_slug)
 
     if os.path.exists(path) and (not os.path.isdir(path) or os.listdir(path)):
         if force_overwrite or click.confirm(
@@ -166,7 +187,7 @@ def create_workspace(
     # clone git project
     clone_project(website_slug=website_slug, path=path, client=client)
 
-    # check for new baseproject + add .aldryn
+    # check for new baseproject + add configuration file
     configure_project(website_slug=website_slug, path=path, client=client)
 
     # setup docker website containers
@@ -191,7 +212,7 @@ def create_workspace(
 
 class DatabaseImportBase(object):
     restore_commands = {
-        "fsm-postgres":{
+        "fsm-postgres": {
             "sql": "psql -U postgres db < {}",
             "binary": (
                 "pg_restore -U postgres --dbname=db -n public "
@@ -203,25 +224,26 @@ class DatabaseImportBase(object):
                 "--no-owner --exit-on-error"
             ),
         },
-        "fsm-mysql":{
+        "fsm-mysql": {
             "sql": "mysql db < {}",
             "binary": "mysql db --binary-mode=1 < {}",
-            "archived-binary": "tar -xzOf {}| mysql db --binary-mode=1"
-        }
-    } 
+            "archived-binary": "tar -xzOf {}| mysql db --binary-mode=1",
+        },
+    }
 
     def __init__(self, *args, **kwargs):
         super(DatabaseImportBase, self).__init__()
         self.client = kwargs.pop("client")
         self.prefix = kwargs.pop("prefix")
         self.db_type = kwargs.pop("db_type")
-        
+
         self.path = kwargs.pop("path", None) or utils.get_project_home()
-        self.website_id = utils.get_aldryn_project_settings(self.path)["id"]
-        self.website_slug = utils.get_aldryn_project_settings(self.path)[
-            "slug"
-        ]
-        self.docker_compose = utils.get_docker_compose_cmd(self.path)
+        self.website_id = utils.get_project_settings(self.path)["id"]
+        self.website_slug = utils.get_project_settings(self.path)["slug"]
+        try:
+            self.docker_compose = utils.get_docker_compose_cmd(self.path)
+        except RuntimeError:
+            self.docker_compose = None
         self.database_extensions = self.get_active_db_extensions()
         self.start_time = time()
 
@@ -240,15 +262,15 @@ class DatabaseImportBase(object):
         self.finish()
 
     def get_active_db_extensions(self):
-        project_settings = utils.get_aldryn_project_settings(self.path)
+        project_settings = utils.get_project_settings(self.path)
         default_db_extensions = ["hstore", "postgis"]
 
         if "db_extensions" in project_settings:
             if not isinstance(project_settings["db_extensions"], list):
                 raise click.ClickException(
-                    '{} file contains invalid "db_extensions" value. '
+                    'Divio configuration file contains invalid "db_extensions" value. '
                     "It should contain a list of extensions, for instance: {}".format(
-                        settings.ALDRYN_DOT_FILE, default_db_extensions
+                        default_db_extensions
                     )
                 )
             return project_settings["db_extensions"]
@@ -331,7 +353,7 @@ class DatabaseImportBase(object):
                         db_container_id,
                         "/bin/bash",
                         "-c",
-                        "mysql --user=root  --execute \"SHOW DATABASES;\"",
+                        'mysql --user=root  --execute "SHOW DATABASES;"',
                     ],
                     catch=False,
                     silent=True,
@@ -365,9 +387,9 @@ class DatabaseImportBase(object):
         sleep(10)
 
         if self.db_type == "fsm-postgres":
-           self.prepare_db_server_postgres(db_container_id, start_wait) 
+            self.prepare_db_server_postgres(db_container_id, start_wait)
         elif self.db_type == "fsm-mysql":
-           self.prepare_db_server_mysql(db_container_id, start_wait)
+            self.prepare_db_server_mysql(db_container_id, start_wait)
         else:
             click.secho("db type not known")
             sys.exit(1)
@@ -379,15 +401,7 @@ class DatabaseImportBase(object):
         restore_command = self.get_db_restore_command(self.db_type)
         # Create db
         check_call(
-            [
-                "docker",
-                "exec",
-                db_container_id,
-                "createdb",
-                "-U",
-                "postgres",
-                "db",
-            ]
+            ["docker", "exec", db_container_id, "createdb", "-U", "postgres", "db"]
         )
 
         if self.database_extensions:
@@ -410,9 +424,7 @@ class DatabaseImportBase(object):
             click.echo("")
             for extension in self.database_extensions:
                 if extension in available_extensions:
-                    click.echo(
-                        "      Enabling extension: {}".format(extension)
-                    )
+                    click.echo("      Enabling extension: {}".format(extension))
                     check_call(
                         [
                             "docker",
@@ -423,9 +435,7 @@ class DatabaseImportBase(object):
                             "postgres",
                             "--dbname=db",
                             "-c",
-                            "CREATE EXTENSION IF NOT EXISTS {};".format(
-                                extension
-                            ),
+                            "CREATE EXTENSION IF NOT EXISTS {};".format(extension),
                         ],
                         silent=True,
                     )
@@ -433,14 +443,7 @@ class DatabaseImportBase(object):
         # TODO: use same dump-type detection like server side on db-api
         try:
             subprocess.call(
-                (
-                    "docker",
-                    "exec",
-                    db_container_id,
-                    "/bin/bash",
-                    "-c",
-                    restore_command,
-                ),
+                ("docker", "exec", db_container_id, "/bin/bash", "-c", restore_command),
                 env=get_subprocess_env(),
             )
         except subprocess.CalledProcessError:
@@ -461,14 +464,7 @@ class DatabaseImportBase(object):
         )
 
         check_call(
-            (
-                "docker",
-                "exec",
-                db_container_id,
-                "/bin/bash",
-                "-c",
-                restore_command,
-            ),
+            ("docker", "exec", db_container_id, "/bin/bash", "-c", restore_command),
             env=get_subprocess_env(),
         )
 
@@ -486,7 +482,6 @@ class DatabaseImportBase(object):
             click.secho("db type not known")
             sys.exit(1)
         click.echo("\n      [{}s]".format(int(time() - start_import)))
-       
 
     def finish(self):
         click.secho("Done", fg="green", nl=False)
@@ -550,7 +545,8 @@ class ImportRemoteDatabase(DatabaseImportBase):
         click.secho(" ---> Preparing download ", nl=False)
         start_preparation = time()
         response = (
-            self.client.download_db_request(self.remote_id, self.stage, self.prefix) or {}
+            self.client.download_db_request(self.remote_id, self.stage, self.prefix)
+            or {}
         )
         progress_url = response.get("progress_url")
         if not progress_url:
@@ -573,9 +569,7 @@ class ImportRemoteDatabase(DatabaseImportBase):
             db_dump_path = download_file(download_url, directory=self.path)
             click.echo(" [{}s]".format(int(time() - start_download)))
             # strip path from dump_path for use in the docker container
-            self.db_dump_path = "/app/{}".format(
-                db_dump_path.replace(self.path, "")
-            )
+            self.db_dump_path = "/app/{}".format(db_dump_path.replace(self.path, ""))
         else:
             click.secho(" -> empty")
             self.db_dump_path = None
@@ -587,15 +581,22 @@ class ImportRemoteDatabase(DatabaseImportBase):
 
 def pull_media(client, stage, remote_id=None, path=None):
     project_home = utils.get_project_home(path)
-    website_id = utils.get_aldryn_project_settings(project_home)["id"]
-    website_slug = utils.get_aldryn_project_settings(project_home)["slug"]
+    website_id = utils.get_project_settings(project_home)["id"]
+    website_slug = utils.get_project_settings(project_home)["slug"]
     remote_id = remote_id or website_id
     remote_project_name = (
-        website_slug
-        if remote_id == website_id
-        else "Project {}".format(remote_id)
+        website_slug if remote_id == website_id else "Project {}".format(remote_id)
     )
-    docker_compose = utils.get_docker_compose_cmd(project_home)
+    try:
+        docker_compose = utils.get_docker_compose_cmd(project_home)
+    except RuntimeError:
+        # Docker-compose does not exist
+        click.secho(
+            "Warning: docker-compose.yml does not exist. Can not handle media without!",
+            fg="red",
+        )
+        return
+
     docker_compose_config = utils.DockerComposeConfig(docker_compose)
 
     local_data_folder = os.path.join(project_home, "data")
@@ -653,12 +654,7 @@ def pull_media(client, stage, remote_id=None, path=None):
         # allow the invoking user to create files inside it.
         check_call(
             docker_compose(
-                "run",
-                "--rm",
-                "web",
-                "chown",
-                str(os.getuid()),
-                remote_data_folder,
+                "run", "--rm", "web", "chown", str(os.getuid()), remote_data_folder
             )
         )
 
@@ -675,17 +671,24 @@ def pull_media(client, stage, remote_id=None, path=None):
 
 def dump_database(dump_filename, db_type, prefix, archive_filename=None):
     project_home = utils.get_project_home()
-    docker_compose = utils.get_docker_compose_cmd(project_home)
+    try:
+        docker_compose = utils.get_docker_compose_cmd(project_home)
+    except RuntimeError:
+        # Docker-compose does not exist
+        click.secho(
+            "Warning: docker-compose.yml does not exist. Can not handle database without!",
+            fg="red",
+        )
+        return
     docker_compose_config = utils.DockerComposeConfig(docker_compose)
 
-
     utils.start_database_server(docker_compose, prefix=prefix)
 
     click.secho(" ---> Dumping local database", nl=False)
     start_dump = time()
     db_container_id = utils.get_db_container_id(project_home, prefix=prefix)
-    #TODO: database
-    if db_type =="fsm-postgres":
+    # TODO: database
+    if db_type == "fsm-postgres":
         subprocess.call(
             (
                 "docker",
@@ -704,7 +707,7 @@ def dump_database(dump_filename, db_type, prefix, archive_filename=None):
             env=get_subprocess_env(),
         )
 
-    elif db_type =="fsm-mysql":
+    elif db_type == "fsm-mysql":
         with open(dump_filename, "w") as f:
             subprocess.call(
                 (
@@ -714,17 +717,16 @@ def dump_database(dump_filename, db_type, prefix, archive_filename=None):
                     "mysqldump",
                     "--user=root",
                     "--compress",
-                    "db"
+                    "db",
                 ),
                 env=get_subprocess_env(),
-                stdout=f
+                stdout=f,
             )
 
     else:
         click.secho("db type not known")
         sys.exit(1)
 
-
     click.echo(" [{}s]".format(int(time() - start_dump)))
 
     if not archive_filename:
@@ -735,19 +737,14 @@ def dump_database(dump_filename, db_type, prefix, archive_filename=None):
     archive_path = os.path.join(project_home, archive_filename)
     sql_dump_size = os.path.getsize(dump_filename)
     click.secho(
-        " ---> Compressing SQL dump ({})".format(pretty_size(sql_dump_size)),
-        nl=False,
+        " ---> Compressing SQL dump ({})".format(pretty_size(sql_dump_size)), nl=False
     )
     start_compress = time()
     with tarfile.open(archive_path, mode="w:gz") as tar:
-        tar.add(
-            os.path.join(project_home, dump_filename), arcname=dump_filename
-        )
+        tar.add(os.path.join(project_home, dump_filename), arcname=dump_filename)
     compressed_size = os.path.getsize(archive_filename)
     click.echo(
-        " {} [{}s]".format(
-            pretty_size(compressed_size), int(time() - start_compress)
-        )
+        " {} [{}s]".format(pretty_size(compressed_size), int(time() - start_compress))
     )
 
 
@@ -761,17 +758,14 @@ def compress_db(dump_filename, archive_filename=None, archive_wd=None):
     archive_path = os.path.join(archive_wd, archive_filename)
     sql_dump_size = os.path.getsize(dump_filename)
     click.secho(
-        " ---> Compressing SQL dump ({})".format(pretty_size(sql_dump_size)),
-        nl=False,
+        " ---> Compressing SQL dump ({})".format(pretty_size(sql_dump_size)), nl=False
     )
     start_compress = time()
     with tarfile.open(archive_path, mode="w:gz") as tar:
         tar.add(os.path.join(archive_wd, dump_filename), arcname=dump_filename)
     compressed_size = os.path.getsize(archive_filename)
     click.echo(
-        " {} [{}s]".format(
-            pretty_size(compressed_size), int(time() - start_compress)
-        )
+        " {} [{}s]".format(pretty_size(compressed_size), int(time() - start_compress))
     )
 
 
@@ -792,15 +786,13 @@ def export_db(prefix):
 
 def push_db(client, stage, remote_id, prefix, db_type):
     project_home = utils.get_project_home()
-    website_id = utils.get_aldryn_project_settings(project_home)["id"]
+    website_id = utils.get_project_settings(project_home)["id"]
     dump_filename = DEFAULT_DUMP_FILENAME
     archive_filename = dump_filename.replace(".sql", ".tar.gz")
     archive_path = os.path.join(project_home, archive_filename)
-    website_slug = utils.get_aldryn_project_settings(project_home)["slug"]
+    website_slug = utils.get_project_settings(project_home)["slug"]
     remote_project_name = (
-        website_slug
-        if remote_id == website_id
-        else "Project {}".format(remote_id)
+        website_slug if remote_id == website_id else "Project {}".format(remote_id)
     )
 
     click.secho(
@@ -811,7 +803,10 @@ def push_db(client, stage, remote_id, prefix, db_type):
     start_time = time()
 
     dump_database(
-        dump_filename=dump_filename, db_type=db_type, prefix=prefix, archive_filename=archive_filename
+        dump_filename=dump_filename,
+        db_type=db_type,
+        prefix=prefix,
+        archive_filename=archive_filename,
     )
 
     click.secho(" ---> Uploading", nl=False)
@@ -849,9 +844,7 @@ def push_local_db(client, stage, dump_filename, website_id, prefix):
     archive_path = os.path.join(archive_wd, archive_filename)
 
     click.secho(
-        " ===> Pushing local database to {} {} environment".format(
-            website_id, stage
-        )
+        " ===> Pushing local database to {} {} environment".format(website_id, stage)
     )
     start_time = time()
 
@@ -892,13 +885,11 @@ def push_local_db(client, stage, dump_filename, website_id, prefix):
 
 def push_media(client, stage, remote_id, prefix):
     project_home = utils.get_project_home()
-    website_id = utils.get_aldryn_project_settings(project_home)["id"]
+    website_id = utils.get_project_settings(project_home)["id"]
     archive_path = os.path.join(project_home, "local_media.tar.gz")
-    website_slug = utils.get_aldryn_project_settings(project_home)["slug"]
+    website_slug = utils.get_project_settings(project_home)["slug"]
     remote_project_name = (
-        website_slug
-        if remote_id == website_id
-        else "Project {}".format(remote_id)
+        website_slug if remote_id == website_id else "Project {}".format(remote_id)
     )
 
     click.secho(
@@ -971,12 +962,16 @@ def update_local_project(git_branch, client, strict=False):
     Makes all updates of the local project.
     """
     project_home = utils.get_project_home()
-    docker_compose = utils.get_docker_compose_cmd(project_home)
+    try:
+        docker_compose = utils.get_docker_compose_cmd(project_home)
+    except RuntimeError:
+        # Docker-compose does not exist
+        docker_compose = None
 
     # We also check for remote repository configurations on a project update
     # to warn the user just in case something changed
     remote_dsn = client.get_repository_dsn(
-        utils.get_aldryn_project_settings(utils.get_project_home())["id"]
+        utils.get_project_settings(utils.get_project_home())["id"]
     )
 
     if remote_dsn and remote_dsn not in get_local_git_remotes():
@@ -990,19 +985,20 @@ def update_local_project(git_branch, client, strict=False):
 
     click.secho("Pulling changes from git remote", fg="green")
     check_call(("git", "pull", "origin", git_branch))
-    click.secho("Pulling docker images", fg="green")
-    check_call(docker_compose("pull"))
-    click.secho("Building local docker images", fg="green")
-    check_call(docker_compose("build"))
-    click.secho("syncing and migrating database", fg="green")
-    if is_windows():
-        # interactive mode is not yet supported with docker-compose
-        # on windows. that's why we have to call it as daemon
-        # and just wait a sane time
-        check_call(docker_compose("run", "-d", "web", "start", "migrate"))
-        sleep(30)
-    else:
-        check_call(docker_compose("run", "web", "start", "migrate"))
+    if docker_compose:
+        click.secho("Pulling docker images", fg="green")
+        check_call(docker_compose("pull"))
+        click.secho("Building local docker images", fg="green")
+        check_call(docker_compose("build"))
+        click.secho("syncing and migrating database", fg="green")
+        if is_windows():
+            # interactive mode is not yet supported with docker-compose
+            # on windows. that's why we have to call it as daemon
+            # and just wait a sane time
+            check_call(docker_compose("run", "-d", "web", "start", "migrate"))
+            sleep(30)
+        else:
+            check_call(docker_compose("run", "web", "start", "migrate"))
 
 
 def develop_package(package, no_rebuild=False):
@@ -1055,9 +1051,12 @@ def develop_package(package, no_rebuild=False):
 
     if not no_rebuild:
         # build web again
-        docker_compose = utils.get_docker_compose_cmd(project_home)
-
-        check_call(docker_compose("build", "web"))
+        try:
+            docker_compose = utils.get_docker_compose_cmd(project_home)
+            check_call(docker_compose("build", "web"))
+        except RuntimeError:
+            # Docker-compose does not exist
+            click.echo("Can not rebuild without docker-compose.yml", fg="red")
 
     click.secho(
         "The package {} has been added to your local development project!".format(
@@ -1067,20 +1066,32 @@ def develop_package(package, no_rebuild=False):
 
 
 def open_project(open_browser=True):
-    docker_compose = utils.get_docker_compose_cmd(utils.get_project_home())
+    try:
+        docker_compose = utils.get_docker_compose_cmd(utils.get_project_home())
+    except RuntimeError:
+        # Docker-compose does not exist
+        click.secho(
+            "Warning: docker-compose.yml does not exist. Can not open project without!",
+            fg="red",
+        )
+        return
+
     CHECKING_PORT = "80"
     try:
         addr = check_output(docker_compose("port", "web", CHECKING_PORT), catch=False)
     except subprocess.CalledProcessError:
-        if click.prompt(
-            "Your project is not running. Do you want to start " "it now?"
-        ):
+        if click.prompt("Your project is not running. Do you want to start " "it now?"):
             return start_project()
         return
     try:
         host, port = addr.rstrip(os.linesep).split(":")
     except ValueError:
-        click.secho("Can not get port of the project. Please check `docker-compose logs` in case the project did not start correctly and please verify that a port {} is exposed.".format(CHECKING_PORT), fg="red")
+        click.secho(
+            "Can not get port of the project. Please check `docker-compose logs` in case the project did not start correctly and please verify that a port {} is exposed.".format(
+                CHECKING_PORT
+            ),
+            fg="red",
+        )
         sys.exit(1)
 
     if host == "0.0.0.0":
@@ -1091,9 +1102,7 @@ def open_project(open_browser=True):
 
     addr = "http://{}:{}/".format(host, port)
 
-    click.secho(
-        "Your project is configured to run at {}".format(addr), fg="green"
-    )
+    click.secho("Your project is configured to run at {}".format(addr), fg="green")
 
     click.secho("Waiting for project to start..", fg="green", nl=False)
     # wait 30s for runserver to startup
@@ -1118,12 +1127,28 @@ def open_project(open_browser=True):
     return addr
 
 
-def start_project():
-    docker_compose = utils.get_docker_compose_cmd(utils.get_project_home())
-    try:
-        check_output(
-            docker_compose("up", "-d"), catch=False, stderr=subprocess.STDOUT
+def configure(client):
+    if click.confirm(
+        "This action will overwrite the local Divio configuration file for your project or create a new one. Do you want to continue?"
+    ):
+        website_slug = click.prompt(
+            "Please enter the application slug of the local project", type=str
         )
+        configure_project(website_slug=website_slug, path=os.getcwd(), client=client)
+
+
+def start_project():
+    try:
+        docker_compose = utils.get_docker_compose_cmd(utils.get_project_home())
+    except RuntimeError:
+        # Docker-compose does not exist
+        click.secho(
+            "Warning: docker-compose.yml does not exist. Can not start project without!",
+            fg="red",
+        )
+        return
+    try:
+        check_output(docker_compose("up", "-d"), catch=False, stderr=subprocess.STDOUT)
     except subprocess.CalledProcessError as exc:
         output = exc.output.decode()
         if "port is already allocated" in output:
@@ -1139,10 +1164,26 @@ def start_project():
 
 
 def show_project_status():
-    docker_compose = utils.get_docker_compose_cmd(utils.get_project_home())
-    check_call(docker_compose("ps"))
+    try:
+        docker_compose = utils.get_docker_compose_cmd(utils.get_project_home())
+        check_call(docker_compose("ps"))
+    except RuntimeError:
+        # Docker-compose does not exist
+        click.secho(
+            "Warning: docker-compose.yml does not exist. Can not show status without!",
+            fg="red",
+        )
+        return
 
 
 def stop_project():
-    docker_compose = utils.get_docker_compose_cmd(utils.get_project_home())
-    check_call(docker_compose("stop"))
+    try:
+        docker_compose = utils.get_docker_compose_cmd(utils.get_project_home())
+        check_call(docker_compose("stop"))
+    except RuntimeError:
+        # Docker-compose does not exist
+        click.secho(
+            "Warning: docker-compose.yml does not exist. Can not stop project without!",
+            fg="red",
+        )
+        return
