@@ -6,9 +6,7 @@ import pytest
 
 def pytest_addoption(parser):
     parser.addoption("--test-project-name", action="store")
-    parser.addoption(
-        "--test-project-directory", action="store", default="test/data"
-    )
+    parser.addoption("--test-project-directory", action="store", default="test/data")
 
 
 @pytest.fixture(scope="session")
@@ -28,14 +26,11 @@ def divio_project(request):
 
     test_project_directory = request.config.option.test_project_directory
 
-    test_project_dir_full_path = os.path.join(
-        test_project_directory, test_project_name
-    )
+    test_project_dir_full_path = os.path.join(test_project_directory, test_project_name)
 
     if not os.path.exists(test_project_dir_full_path):
         process = subprocess.Popen(
-            ["divio", "project", "setup", test_project_name],
-            cwd=test_project_directory,
+            ["divio", "project", "setup", test_project_name], cwd=test_project_directory
         )
         stdout, stderr = process.communicate()
     return test_project_dir_full_path
